aboutsummaryrefslogtreecommitdiffstats
path: root/src/jcgp/backend/function
diff options
context:
space:
mode:
authorEduardo Pedroni <ep625@york.ac.uk>2014-05-01 13:09:07 +0100
committerEduardo Pedroni <ep625@york.ac.uk>2014-05-01 13:09:07 +0100
commitc4fc7e307caf03c93c4203aff8960ffcb3ca8737 (patch)
tree10a84adee6a9b422ad5d28597d2a85fd3b6b50dd /src/jcgp/backend/function
parent36f4393bcc9e55afa2334baa33e603ce839741a1 (diff)
parente354311547a5a5f4d817e6af5b7df99813d66ecb (diff)
Merged with repo, there were unsynced changes
Diffstat (limited to 'src/jcgp/backend/function')
-rw-r--r--src/jcgp/backend/function/FunctionSet.java10
-rw-r--r--src/jcgp/backend/function/SymbolicRegressionFunctions.java2
2 files changed, 6 insertions, 6 deletions
diff --git a/src/jcgp/backend/function/SymbolicRegressionFunctions.java b/src/jcgp/backend/function/SymbolicRegressionFunctions.java
index 6f72723..9c6a3b1 100644
--- a/src/jcgp/backend/function/SymbolicRegressionFunctions.java
+++ b/src/jcgp/backend/function/SymbolicRegressionFunctions.java
@@ -208,7 +208,7 @@ public class SymbolicRegressionFunctions extends FunctionSet {
}
/**
- * Exponential function. Returns the exponential of input 0.
+ * Exponential function. Returns e raised to input 0.
*
* @see Math
*/
diff --git a/src/jcgp/backend/function/FunctionSet.java b/src/jcgp/backend/function/FunctionSet.java
index 052183a..abc9eb4 100644
--- a/src/jcgp/backend/function/FunctionSet.java
+++ b/src/jcgp/backend/function/FunctionSet.java
@@ -69,16 +69,16 @@ public abstract class FunctionSet {
/**
* Computes and returns the maximum arity out of
* all the function, enabled or disabled.
*
- * @return
+ * @return the problem's current maximum arity.
*/
public int getMaxArity(){
int arity = 0;
- for (Function function : functionList) {
+ for (Integer function : allowedFunctions) {
// if a higher arity is found, store it
- if (function.getArity() > arity) {
- arity = function.getArity();
+ if (functionList.get(function).getArity() > arity) {
+ arity = functionList.get(function).getArity();
}
}
return arity;
@@ -69,16 +69,16 @@ public abstract class FunctionSet {
/**
* Computes and returns the maximum arity out of
- * all the function, enabled or disabled.
+ * all enabled functions.
*